import { JSXElement, Show, onCleanup, useContext } from "solid-js";

import { LoginForm } from "../Components/Login";
import { RegisterForm } from "../Components/Register";
import { ModalContext } from "../Context/GlobalState";

export function LoginModal(): JSXElement {
  const modal_ctx = useContext(ModalContext)!;

  const closeModal = (): void => {
    modal_ctx.setOpen(false);
  };

  // Close the modal when the component is unmounted
  onCleanup(() => {
    modal_ctx.setOpen(false);
  });

  return (
    <Show when={modal_ctx.isOpen()}>
      <dialog class="modal modal-open">
        <div class="modal-box">
          <form method="dialog">
            <button
              onClick={closeModal}
              class="btn btn-circle btn-ghost btn-sm absolute right-2 top-2"
            >
              ✕
            </button>
          </form>
          <h3 class="mb-2 text-lg font-bold">Welcome!</h3>
          <div class="tabs tabs-lifted">
            <input
              type="radio"
              name="login_tabs"
              class="tab"
              aria-label="Login"
              checked
            />
            <div class="tab-content rounded-box border-base-300 bg-base-100 p-10">
              <LoginForm />
            </div>

            <input
              type="radio"
              name="login_tabs"
              class="tab"
              aria-label="Register"
            />
            <div class="tab-content rounded-box border-base-300 bg-base-100 p-10">
              <RegisterForm />
            </div>
          </div>
        </div>
        <form method="dialog" class="modal-backdrop">
          <button onClick={closeModal}>close</button>
        </form>
      </dialog>
    </Show>
  );
}
